import 'core-js';
import 'zone.js/dist/zone';
import 'zone.js/dist/long-stack-trace-zone';
import 'zone.js/dist/proxy';
import 'zone.js/dist/sync-test';
import 'zone.js/dist/jasmine-patch';
import 'zone.js/dist/async-test';
import 'zone.js/dist/fake-async-test';
import { CacheService, MESSAGES } from './cache.service';
import { async, TestBed } from '@angular/core/testing';
import { BrowserDynamicTestingModule, platformBrowserDynamicTesting } from '@angular/platform-browser-dynamic/testing';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/observable/of';
TestBed.initTestEnvironment(BrowserDynamicTestingModule, platformBrowserDynamicTesting());
describe('CacheService', function () {
    var service;
    beforeAll(function () {
        service = new CacheService();
    });
    afterAll(async(function () {
        service.clearAll();
    }));
    it('should create an instance of the service', function () { return expect(service).toBeDefined(); });
    it('should save item to storage (async)', async(function () {
        service.saveItem('name', 'ibby')
            .then(function () { return expect(true).toBeTruthy(); })
            .catch(function () { return expect(false).toBeTruthy(); });
    }));
    it('should get previously stored value (async)', async(function () {
        service.getItem('name')
            .then(function (value) { return expect(value).toEqual('ibby'); })
            .catch(function () { return expect(false).toBeTruthy(); });
    }));
    it('should disable cache', function () {
        service.enableCache(false);
        expect(service.cacheEnabled === false).toBeTruthy();
    });
    it('should throw an error when getting item and cache is disabled', async(function () {
        service.getItem('name')
            .then(function () { return expect(false).toBeTruthy(); })
            .catch(function (e) { return expect(e).toEqual(MESSAGES[1]); });
    }));
    it('should enable cache', function () {
        service.enableCache(true);
        expect(service.cacheEnabled === true).toBeTruthy();
    });
});
describe('Observable Caching', function () {
    var key = 'http_cache_test';
    var mockData = {
        hello: 'world'
    };
    var observable = Observable.of(mockData);
    var service;
    beforeAll(function () {
        service = new CacheService();
    });
    beforeEach(function () {
        spyOn(observable, 'subscribe').and.callThrough();
    });
    afterAll(function (done) {
        service.clearAll()
            .then(function () { return done(); })
            .catch(function () { return done(); });
    });
    it('should create an instance of the service', function () {
        expect(service).toBeDefined();
    });
    // it('', inject([XHRBackend, CacheService], (mockBackend: XHRBackend, cache: CacheService) => { }))
    it('should return data from observable (async)', function (done) {
        service.loadFromObservable(key, observable)
            .subscribe(function (res) {
            expect(res).toBeDefined();
            expect(observable.subscribe).toHaveBeenCalled();
            expect(res).toEqual(mockData);
            done();
        });
    });
    it('should return cached observable data (async)', function (done) {
        service.loadFromObservable(key, observable)
            .subscribe(function (res) {
            expect(observable.subscribe).not.toHaveBeenCalled();
            expect(res).toEqual(mockData);
            done();
        });
    });
});
//# sourceMappingURL=cache.service.spec.js.map